@@ -1,23 +1,23 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-#pragma once
+#ifndef RNDC_UTIL_H
+#define RNDC_UTIL_H 1
 
 /*! \file */
 
 #include <isc/attributes.h>
 #include <isc/formatcheck.h>
 #include <isc/lang.h>
+#include <isc/platform.h>
 
 #define NS_CONTROL_PORT 953
 
@@ -40,3 +40,5 @@ ISC_NORETURN void
 fatal(const char *format, ...) ISC_FORMAT_PRINTF(1, 2);
 
 ISC_LANG_ENDDECLS
+
+#endif /* RNDC_UTIL_H */
