@@ -1,12 +1,10 @@
 #!/usr/bin/perl
-
+#
 # Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
-# SPDX-License-Identifier: MPL-2.0
-#
 # This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0.  If a copy of the MPL was not distributed with this
-# file, you can obtain one at https://mozilla.org/MPL/2.0/.
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
@@ -65,21 +63,6 @@
 #  pattern, only this data will be signed. Currently, this is only
 #  done for TCP.
 #
-# /pattern NOTIMP <key> <key_data>/
-# /pattern NOTIMP/
-#
-# Return a NOTIMP response
-#
-# /pattern EDNS=NOTIMP <key> <key_data>/
-# /pattern EDNS=NOTIMP/
-#
-# Return a NOTIMP response to an EDNS request
-#
-# /pattern EDNS=FORMERR <key> <key_data>/
-# /pattern EDNS=FORMERR/
-#
-# Return a FORMERR response to an EDNS request
-#
 # /pattern bad-id <key> <key_data>/
 # /pattern bad-id/
 #
@@ -110,8 +93,6 @@ my $mainport = int($ENV{'PORT'});
 if (!$mainport) { $mainport = 5300; }
 my $ctrlport = int($ENV{'EXTRAPORT1'});
 if (!$ctrlport) { $ctrlport = 5301; }
-my $hmac_algorithm = $ENV{'DEFAULT_HMAC'};
-if (!defined($hmac_algorithm)) { $hmac_algorithm = "hmac-sha256"; }
 
 # XXX: we should also be able to set the port numbers to listen on.
 my $ctlsock = IO::Socket::INET->new(LocalAddr => "$server_addr",
@@ -191,7 +172,6 @@ sub handleUDP {
 				} else {
 					$tsig = Net::DNS::RR->new(
 							name => $key_name,
-							algorithm => $hmac_algorithm,
 							type => 'TSIG',
 							key  => $key_data);
 				}
@@ -220,7 +200,7 @@ sub handleUDP {
 							 $prev_tsig->mac);
 					}
 				}
-
+				
 				$packet->sign_tsig($tsig);
 			}
 			last;
@@ -268,7 +248,7 @@ sub packetlen {
 	} else {
 		($header, $offset) = Net::DNS::Header->parse(\$data);
 	}
-
+		
 	for (1 .. $header->qdcount) {
 		if ($decode) {
 			($q, $offset) =
@@ -354,17 +334,12 @@ sub handleTCP {
 		($request, $err) = new Net::DNS::Packet(\$buf, 0);
 		$err and die $err;
 	}
-
+	
 	my @questions = $request->question;
 	my $qname = $questions[0]->qname;
 	my $qtype = $questions[0]->qtype;
 	my $qclass = $questions[0]->qclass;
 	my $id = $request->header->id;
-	my @additional = $request->additional;
-	my $has_opt = 0;
-	foreach (@additional) {
-		$has_opt = 1 if (ref($_) eq 'Net::DNS::RR::OPT');
-	}
 
 	my $opaque;
 
@@ -396,60 +371,23 @@ sub handleTCP {
 		if ("$qname $qtype" =~ /$dbtype/) {
 			$count_these++;
 			my $a;
-			my $done = 0;
-
-			while (defined($key_name) &&
-			       ($key_name eq "NOTIMP" || $key_name eq "EDNS=NOTIMP" ||
-				$key_name eq "EDNS=FORMERR" || $key_name eq "bad-id")) {
-
-				if (defined($key_name) && $key_name eq "NOTIMP") {
-					$packet->header->rcode('NOTIMP') if (!$done);
-					$key_name = $key_data;
-					($key_data, $tname) = split(/ /,$tname);
-					$done = 1;
-				}
-
-				if (defined($key_name) && $key_name eq "EDNS=NOTIMP") {
-					if ($has_opt) {
-						$packet->header->rcode('NOTIMP') if (!$done);
-						$done = 1;
-					}
-					$key_name = $key_data;
-					($key_data, $tname) = split(/ /,$tname);
-				}
-
-				if (defined($key_name) && $key_name eq "EDNS=FORMERR") {
-					if ($has_opt) {
-						$packet->header->rcode('FORMERR') if (!$done);
-						$done = 1;
-					}
-					$key_name = $key_data;
-					($key_data, $tname) = split(/ /,$tname);
-				}
-
-				if (defined($key_name) && $key_name eq "bad-id") {
-					$packet->header->id(($id+50)%0xffff);
-					$key_name = $key_data;
-					($key_data, $tname) = split(/ /,$tname);
-				}
+			foreach $a (@{$r->{answer}}) {
+				$packet->push("answer", $a);
 			}
-
-			if (!$done) {
-				foreach $a (@{$r->{answer}}) {
-					$packet->push("answer", $a);
-				}
+			if (defined($key_name) && $key_name eq "bad-id") {
+				$packet->header->id(($id+50)%0xffff);
+				$key_name = $key_data;
+				($key_data, $tname) = split(/ /,$tname)
 			}
-
 			if (defined($key_name) && defined($key_data)) {
 				my $tsig;
 				# sign the packet
-				print "  Signing the data with " .
+				print "  Signing the data with " . 
 				      "$key_name/$key_data\n";
 
 				if ($Net::DNS::VERSION < 0.69) {
 					$tsig = Net::DNS::RR->new(
 						   "$key_name TSIG $key_data");
-					$tsig->algorithm = $hmac_algorithm;
 				} elsif ($Net::DNS::VERSION >= 0.81 &&
 					 $continuation) {
 				} elsif ($Net::DNS::VERSION >= 0.75 &&
@@ -458,7 +396,6 @@ sub handleTCP {
 				} else {
 					$tsig = Net::DNS::RR->new(
 							name => $key_name,
-							algorithm => $hmac_algorithm,
 							type => 'TSIG',
 							key  => $key_data);
 				}
@@ -487,7 +424,7 @@ sub handleTCP {
 							 $prev_tsig->mac);
 					}
 				}
-
+				
 				$tsig->sign_func($signer) if defined($signer);
 				$tsig->continuation($continuation) if
 					 ($Net::DNS::VERSION >= 0.71 &&
@@ -509,7 +446,6 @@ sub handleTCP {
 			}
 			#$packet->print;
 			push(@results,$packet->data);
-			last if ($done);
 			if ($tname eq "") {
 				$tname = $qname;
 			}
